@@ -72,6 +72,9 @@ sub _delete {
         }
     }
     $memd->delete($_) for @ids;
+
+    #return array of deleted
+    [@_];
 }
 
 sub _create {
@@ -80,15 +83,16 @@ sub _create {
     my $memd    = $self->_mem_cache;
     my $ns      = $self->_ns;
     $ns = '' unless defined $ns;
+    my %res = ();
     while ( my ( $key, $val ) = each %to_save ) {
-        $memd->set( $ns . $key, $val );
+        $memd->set( $ns . $key, $val ) && $res{$key}++;
     }
-    return \%to_save;
+    return \%res;
 }
 
 sub _fetch {
     my $self = shift;
-    my @ids  =  @_;
+    my @ids  = @_;
     my $ns   = $self->_ns;
     if ( defined $ns ) {
 
